"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createForbiddenWordsDictionary = void 0;
const cspell_trie_lib_1 = require("cspell-trie-lib");
const SpellingDictionaryFromTrie_1 = require("./SpellingDictionaryFromTrie");
const createSpellingDictionary_1 = require("./createSpellingDictionary");
class ForbiddenWordsDictionary {
    constructor(name, source, wordList) {
        this.name = name;
        this.source = source;
        this.containsNoSuggestWords = false;
        this.options = {};
        this.type = 'forbidden';
        this.isDictionaryCaseSensitive = true;
        const words = (0, cspell_trie_lib_1.parseDictionaryLines)(wordList, { stripCaseAndAccents: false });
        const trie = (0, cspell_trie_lib_1.buildTrieFast)(words);
        this.dict = new SpellingDictionaryFromTrie_1.SpellingDictionaryFromTrie(trie, name, createSpellingDictionary_1.defaultOptions, source);
    }
    /**
     * A Forbidden word list does not "have" valid words.
     * Therefore it always returns false.
     * @param _word - the word
     * @param _options - options
     * @returns always false
     */
    has(_word, _options) {
        return false;
    }
    /** A more detailed search for a word, might take longer than `has` */
    find(word, options) {
        const r = this.dict.find(word, options);
        if (!r || r.found === false || r.forbidden)
            return undefined;
        return { ...r, forbidden: true };
    }
    isForbidden(word) {
        const r = this.find(word);
        if (!r)
            return false;
        return r.forbidden && r.found !== false;
    }
    isNoSuggestWord(_word, _options) {
        return false;
    }
    suggest() {
        return [];
    }
    genSuggestions() {
        return;
    }
    mapWord(word) {
        return word;
    }
    get size() {
        return this.dict.size;
    }
    getErrors() {
        return [];
    }
}
/**
 * Create a dictionary where all words are to be forbidden.
 * @param wordList - list of words
 * @param name
 * @param source
 * @param options
 * @returns
 */
function createForbiddenWordsDictionary(wordList, name, source) {
    return new ForbiddenWordsDictionary(name, source, wordList);
}
exports.createForbiddenWordsDictionary = createForbiddenWordsDictionary;
//# sourceMappingURL=ForbiddenWordsDictionary.js.map